==> moniwiki-1.0.tgz: moniwiki/plugin/rename.php <==
<?php
// Copyright 2003 by Won-Kyu Park <wkpark at kldp.org>
// All rights reserved. Distributable under GPL see COPYING
// rename action plugin for the MoniWiki
//
// $Id: rename.php,v 1.1 2003/06/30 22:40:07 wkpark Exp wkpark $

function do_rename($formatter,$options) {
  global $DBInfo;
  
  if (isset($options['value'])) {
    if ($DBInfo->hasPage($options['page']) && !$DBInfo->hasPage($options['value'])) {
      $DBInfo->renamePage($options['page'],$options['value']);
      $title = sprintf(_("\"%s\" is renamed !"), $options['page']);
      $formatter->send_header("",$options);
      $formatter->send_title($title,"",$options);
      $formatter->send_footer("",$options);
      return;
    } else {
      $title = sprintf(_("Fail to rename \"%s\" !"), $options['page']);
      $formatter->send_header("",$options);
      $formatter->send_title($title,"",$options);
      $formatter->send_footer("",$options);
      return;
    }
  }
  $title = sprintf(_("Rename \"%s\" ?"), $options['page']);
  $formatter->send_header("",$options);
  $formatter->send_title($title,"",$options);
#<tr><td align='right'><input type='checkbox' name='show' checked='checked' />show only </td><td><input type='password' name='passwd'>
  print "<form method='post'>
<table border='0'>
<tr><td align='right'>Old name: </td><td><b>$options[page]</b></td></tr>
<tr><td align='right'>New name: </td><td><input name='value' /></td></tr>\n";
  print "<tr><td valign='top'>"._("with version info").":</td><td><input type='checkbox' name='with_history' /></td></tr>\n";
  if ($DBInfo->security->is_protected("rename",$options))
  print "<tr><td align='right'>
 Password: </td><td><input type='password' name='passwd' />
<input type='submit' name='button_rename' value='rename' />".
_("Only WikiMaster can rename this page")."</td></tr>\n";

  print "
</table>
    <input type=hidden name='action' value='rename' />
    </form>";
#  $formatter->send_page();
  $formatter->send_footer("",$options);
}
?>

==> moniwiki-1.0.2.tgz: moniwiki/plugin/rename.php <==
<?php
// Copyright 2003 by Won-Kyu Park <wkpark at kldp.org>
// All rights reserved. Distributable under GPL see COPYING
// a rename action plugin for the MoniWiki
//
// $Id: rename.php,v 1.3 2003/08/15 21:30:36 wkpark Exp $

function do_rename($formatter,$options) {
  global $DBInfo;
  
  if (isset($options['value'])) {
    if ($DBInfo->hasPage($options['page']) && !$DBInfo->hasPage($options['value'])) {
      $DBInfo->renamePage($options['page'],$options['value'],$options);
      $title = sprintf(_("\"%s\" is renamed !"), $options['page']);
      $formatter->send_header("",$options);
      $formatter->send_title($title,"",$options);
      $formatter->send_footer("",$options);
      return;
    } else {
      $title = sprintf(_("Fail to rename \"%s\" !"), $options['page']);
      $formatter->send_header("",$options);
      $formatter->send_title($title,"",$options);
      $formatter->send_footer("",$options);
      return;
    }
  }
  $title = sprintf(_("Rename \"%s\" ?"), $options['page']);
  $formatter->send_header("",$options);
  $formatter->send_title($title,"",$options);
#<tr><td align='right'><input type='checkbox' name='show' checked='checked' />show only </td><td><input type='password' name='passwd'>
  print "<form method='post'>
<table border='0'>
<tr><td align='right'>Old name: </td><td><b>$options[page]</b></td></tr>
<tr><td align='right'>New name: </td><td><input name='value' /></td></tr>\n";
  if ($DBInfo->security->is_protected("rename",$options))
    print "<tr><td align='right'>"._("Password").": </td><td><input type='password' name='passwd' /> ".
    _("Only WikiMaster can rename this page");
  print "<tr>";
  print "<td>"._("with revision history")."<input type='checkbox' name='history' /></td>";
  print "<td><input type='submit' name='button_rename' value='rename' /></td>";
  print "</td></tr>\n";

  print "
</table>
    <input type=hidden name='action' value='rename' />
    </form>";
#  $formatter->send_page();
  $formatter->send_footer("",$options);
}
?>
